.. raw:: html

   <div style="display: flex; justify-content: space-between; align-items: center; margin-bottom: 1em;">
     <h1 style="margin: 0;">OSL Dynamics Toolbox</h1>
     <div>
       <a href="https://www.win.ox.ac.uk/research/our-locations/OHBA" target="_blank">
         <img src="https://avatars.githubusercontent.com/u/15248840?s=200&v=4" width="125px">
       </a>
       <a href="https://www.win.ox.ac.uk" target="_blank">
         <img src="https://www.win.ox.ac.uk/images/site-logos/oxcin_logo.png" width="220px">
       </a>
     </div>
   </div>

This package contains models for analysing neuroimaging data. In particular, this package contains methods (based on generative models) for studying dynamics in time series data. This package can be used for:

- Inferring and visualising dynamic (and static) functional networks.
- Spectral estimation: including multitaper spectra and wavelet transforms.
- Burst detection.
- Statistical significant testing (using GLM permutation testing).
- Simulating time series data (e.g. HMMs, autoregressive models, etc).
- And much more!

For more information on how to use osl-dynamics see the :doc:`documentation <documentation>`.

If you would like to request new features or if you're confident that you have found a bug, please create a new issue on the `GitHub issues <https://github.com/OHBA-analysis/osl-dynamics/issues>`_ page.

This package was developed by the Oxford Centre for Human Brain Activity (OHBA) Methods Group at the University of Oxford. Our group website is `here <https://www.psych.ox.ac.uk/research/ohba-analysis-group>`_.

If you find this toolbox useful, please cite:

    **Chetan Gohil, Rukuang Huang, Evan Roberts, Mats WJ van Es, Andrew J Quinn, Diego Vidaurre, Mark W Woolrich (2024) osl-dynamics, a toolbox for modeling fast dynamic brain activity eLife 12:RP91949.**

-----------------------

Contents
========

.. toctree::
   :maxdepth: 2

   Install <install>
   Documentation <documentation>
   FAQ <faq>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
